const path = require('node:path');

module.exports = {
	description: 'tree-shakes entities referenced in a return statement after an error'
};
